package be.iminds.ilabt.jfed.ui.cli2.instruction;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import java.util.List;

public class UserInfoInstruction extends Instruction {
    private final boolean showUserUrn;
    private final boolean listSlices;
    private final boolean listProjects;

    @JsonCreator
    public UserInfoInstruction(@JsonProperty("action") @Nonnull Action action,
                               @JsonProperty("user") @Nullable User user,
                               @JsonProperty("interactive") @Nullable Boolean interactive,
                               @JsonProperty("actionOutputs") @Nullable List<ActionOutput> actionOutputs,
                               @JsonProperty("debugOutputs") @Nullable List<DebugOutput> debugOutputs,
                               @JsonProperty("callOutputs") @Nullable List<CallOutput> callOutputs,
                               @JsonProperty("showUserUrn") @Nullable Boolean showUserUrn,
                               @JsonProperty("listSlices") @Nullable Boolean listSlices,
                               @JsonProperty("listProjects") @Nullable Boolean listProjects) {
        super(action, user, interactive, actionOutputs, debugOutputs, callOutputs);
        this.showUserUrn = showUserUrn == null ? new UserInfoInstruction().showUserUrn : showUserUrn;
        this.listSlices = listSlices == null ? new UserInfoInstruction().listSlices : listSlices;
        this.listProjects = listProjects == null ? new UserInfoInstruction().listProjects : listProjects;
    }

    public UserInfoInstruction() {
        super(Action.USERINFO);
        this.showUserUrn = true;
        this.listSlices = true;
        this.listProjects = true;
    }

    @JsonProperty
    public boolean isShowUserUrn() {
        return showUserUrn;
    }

    @JsonProperty
    public boolean isListSlices() {
        return listSlices;
    }

    @JsonProperty
    public boolean isListProjects() {
        return listProjects;
    }

    @JsonIgnore
    @Nonnull
    @Override
    public Action getActionOfClass() {
        return Action.USERINFO;
    }
}
